@@ -82,9 +82,11 @@ bool List::listCollection(const Collection & root, int depth, const QStack<Colle
     }
   }
 
+  const bool isUnsubscribed = mOnlySubscribed && !root.subscribed();
+
   // filter if this node isn't needed by it's children
-  bool hidden = (mResource.isValid() && root.resourceId() != mResource.id())
-      || (mOnlySubscribed && !root.subscribed())
+  const bool hidden = (mResource.isValid() && root.resourceId() != mResource.id())
+      || isUnsubscribed
       || (!mMimeTypes.isEmpty() && !intersect( mMimeTypes, root.mimeTypes()) );
 
   if ( !childrenFound && hidden )
@@ -94,7 +96,7 @@ bool List::listCollection(const Collection & root, int depth, const QStack<Colle
   Collection dummy = root;
   DataStore *db = connection()->storageBackend();
   db->activeCachePolicy( dummy );
-  const QByteArray b = HandlerHelper::collectionToByteArray( dummy, hidden, mIncludeStatistics, mAncestorDepth, ancestors );
+  const QByteArray b = HandlerHelper::collectionToByteArray( dummy, isUnsubscribed, mIncludeStatistics, mAncestorDepth, ancestors );
 
   Response response;
   response.setUntagged();
