@@ -118,7 +118,12 @@ void Akonadi::DataStore::close()
 
 bool Akonadi::DataStore::init()
 {
-  DbInitializer::Ptr initializer = DbInitializer::createInstance( m_database, QLatin1String(":akonadidb.xml") );
+  QString dbtemplate = QLatin1String(":akonadidb.xml");
+#ifdef Q_OS_WINCE
+  dbtemplate = QLatin1String(":akonadidb-mobile.xml");
+#endif
+
+  DbInitializer::Ptr initializer = DbInitializer::createInstance( m_database, dbtemplate );
   if (! initializer->run() ) {
     akError() << initializer->errorMsg();
     return false;
@@ -297,6 +302,8 @@ bool Akonadi::DataStore::moveCollection( Collection & collection, const Collecti
   if ( !m_dbOpened || !newParent.isValid() )
     return false;
 
+  const QByteArray oldResource = collection.resource().name().toLatin1();
+
   int resourceId = collection.resourceId();
   const Collection source = collection.parent();
   if ( newParent.id() > 0 ) // not root
@@ -314,7 +321,7 @@ bool Akonadi::DataStore::moveCollection( Collection & collection, const Collecti
   if ( !collection.update() )
     return false;
 
-  mNotificationCollector->collectionMoved( collection, source );
+  mNotificationCollector->collectionMoved( collection, source, oldResource, newParent.resource().name().toLatin1() );
   return true;
 }
 
